Title: My super title
Date: 2010-12-03 10:20
Modified: 2010-12-05 19:30
Category: Python
Tags: pelican, publishing
Slug: my-super-post-md
Authors: Alexis Metaireau, Conan Doyle
Summary: Short version for index and feeds

This is the content of my super blog post.

Intra-Site Links:

[a link relative to the current file]({filename}testfile_link.md)

[1]: {filename}testfile_link.md

[link text itself]: {filename}testfile_link.md
